summaryrefslogtreecommitdiffstats
diff options
context:
space:
mode:
-rw-r--r--src/Authoring/Studio/Application/StudioApp.cpp4
1 files changed, 2 insertions, 2 deletions
diff --git a/src/Authoring/Studio/Application/StudioApp.cpp b/src/Authoring/Studio/Application/StudioApp.cpp
index a9da142b..a662cc03 100644
--- a/src/Authoring/Studio/Application/StudioApp.cpp
+++ b/src/Authoring/Studio/Application/StudioApp.cpp
@@ -438,7 +438,7 @@ bool CStudioApp::handleWelcomeRes(int res, bool recursive)
case StudioTutorialWidget::openSampleResult: {
if (PerformSavePrompt()) {
// Try three options:
// - open a specific example .uip
// - failing that, show the main example root dir
// - failing all previous, show default Documents dir
QFileInfo filePath;
@@ -465,7 +465,7 @@ bool CStudioApp::handleWelcomeRes(int res, bool recursive)
}
theFile = m_dialogs->GetFileOpenChoice(filePath.absoluteFilePath());
} else {
- theFile = filePath.absoluteFilePath() + QStringLiteral("/SampleProject.uip");
+ theFile = filePath.absoluteFilePath() + QStringLiteral("/SampleProject.uia");
}
if (!theFile.isEmpty()) {
@@ -438,7 +438,7 @@ bool CStudioApp::handleWelcomeRes(int res, bool recursive)
if (PerformSavePrompt()) {
// Try three options:
- // - open a specific example .uip
+ // - open a specific example .uia
// - failing that, show the main example root dir
// - failing all previous, show default Documents dir